@@ -3,7 +3,7 @@ from typing import Iterator, Optional
 
 from cognite.seismic._api.api import API
 from cognite.seismic._api.grpc_helpers import get_single_item
-from cognite.seismic._api.utility import Metadata, get_coverage_spec, get_identifier
+from cognite.seismic._api.utility import Metadata, _get_coverage_spec, _get_identifier
 from cognite.seismic.data_classes.api_types import SeismicStore
 from cognite.seismic.data_classes.extents import TraceHeaderField
 from cognite.seismic.data_classes.searchspec import SearchSpecBase, SearchSpecGetAll, SearchSpecSeismicStore
@@ -14,6 +14,7 @@ if not os.getenv("READ_THE_DOCS"):
         DeleteSeismicStoreRequest,
         EditSeismicStoreRequest,
     )
+    from google.protobuf.wrappers_pb2 import StringValue
 
 
 class SeismicStoreAPI(API):
@@ -81,7 +82,7 @@ class SeismicStoreAPI(API):
         req = search_spec._to_search_seismicstores_request()
 
         if coverage_crs is not None or coverage_format is not None:
-            coverage = get_coverage_spec(coverage_crs, coverage_format)
+            coverage = _get_coverage_spec(coverage_crs, coverage_format)
             req.coverage.MergeFrom(coverage)
 
         req.include_file_info = include_file_info
@@ -91,7 +92,7 @@ class SeismicStoreAPI(API):
             req.extent_key = extent_key._to_proto()
         req.include_extent = include_extent
 
-        return (SeismicStore._from_proto(s, self._api_client) for s in self.query.SearchSeismicStores(req))
+        return (SeismicStore._from_proto(s, self._api_client.traces) for s in self.query.SearchSeismicStores(req))
 
     def list(
         self,
@@ -181,13 +182,13 @@ class SeismicStoreAPI(API):
         Returns:
             :py:class:`~cognite.seismic.SeismicStore`:
         """
-        identifier = get_identifier(id, external_id)
+        identifier = _get_identifier(id, external_id)
         request = EditSeismicStoreRequest(seismic_store=identifier)
         if new_name is not None:
-            request.name = new_name
+            request.name.MergeFrom(StringValue(value=new_name))
         if metadata is not None:
             request.metadata.MergeFrom(OptionalMap(data=metadata))
-        return SeismicStore._from_proto(self.query.EditSeismicStore(request), self._api_client)
+        return SeismicStore._from_proto(self.query.EditSeismicStore(request), self._api_client.traces)
 
     def delete(self, *, id: Optional[int] = None, external_id: Optional[str] = None):
         """Delete a seismic store.
@@ -199,5 +200,5 @@ class SeismicStoreAPI(API):
             external_id (str, optional): The id or the external id of the seismic store to delete
         """
 
-        request = DeleteSeismicStoreRequest(seismic_store=get_identifier(id, external_id))
+        request = DeleteSeismicStoreRequest(seismic_store=_get_identifier(id, external_id))
         self.query.DeleteSeismicStore(request)
