@@ -6,8 +6,6 @@ if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.types_pb2 import CRS, GeoJson, Geometry, Wkt
     from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import CoverageSpec, Identifier, SearchSpec
     from google.protobuf.struct_pb2 import Struct
-else:
-    from cognite.seismic._api.shims import CoverageSpec, Identifier
 
 
 Metadata = Dict[str, str]
@@ -21,7 +19,7 @@ class Direction(Enum):
     XLINE = 1
 
 
-def get_identifier(id: Optional[int] = None, external_id: Optional[str] = None) -> Identifier:
+def _get_identifier(id: Optional[int] = None, external_id: Optional[str] = None) -> "Identifier":
     """Turn an id or external id into a v1.Identifier.
 
     Returns:
@@ -43,7 +41,7 @@ def get_search_spec(
     name: Optional[str] = None,
     name_substring: Optional[str] = None,
     uuid: Optional[str] = None,
-):
+) -> "SearchSpec":
     """Turns kwargs into a SearchSpec.
 
     Returns:
@@ -65,15 +63,15 @@ def get_search_spec(
     return spec
 
 
-def get_coverage_spec(crs: Optional[str] = None, format: Optional[str] = None) -> CoverageSpec:
+def _get_coverage_spec(crs: Optional[str] = None, format: Optional[str] = None) -> "CoverageSpec":
     """Turns an optional crs and an optional string into a CoverageSpec."""
     if format is None:
         format = "wkt"
 
     if format == "wkt":
-        return CoverageSpec(crs=crs, format=0)
+        return CoverageSpec(crs=crs or "", format=CoverageSpec.Format.ValueType(0))
     elif format == "geojson":
-        return CoverageSpec(crs=crs, format=1)
+        return CoverageSpec(crs=crs or "", format=CoverageSpec.Format.ValueType(1))
     else:
         raise ValueError(f"Unknown format {format}")
 
@@ -96,7 +94,7 @@ def make_geometry(crs: Optional[str] = None, wkt: Optional[str] = None, geo_json
         return None
 
 
-def get_exact_match_filter(metadata: Mapping[str, str]):
+def _get_exact_match_filter(metadata: Mapping[str, str]):
     """Create an exact key-value match for SearchSpec"""
 
     from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Filter, KeyValueExactMatch, MetadataFilter
