@@ -3,17 +3,11 @@ import logging
 import os
 import time
 from collections import namedtuple
-from typing import Callable
+from typing import Callable, List, Tuple
 
 import certifi
 import grpc
-from grpc._channel import (
-    _InactiveRpcError,
-    _SingleThreadedUnaryStreamMultiCallable,
-    _StreamStreamMultiCallable,
-    _UnaryStreamMultiCallable,
-    _UnaryUnaryMultiCallable,
-)
+from grpc import StreamStreamMultiCallable, UnaryStreamMultiCallable, UnaryUnaryMultiCallable
 
 if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic._api.file import FileAPI
@@ -48,7 +42,7 @@ def with_retry(f, transactional=False):
         while True:
             try:
                 return f(*args, **kwargs)
-            except _InactiveRpcError as e:
+            except grpc.RpcError as e:
                 attempts += 1
                 code = e.code()
 
@@ -75,10 +69,9 @@ def decorate_with_retries(*args):
     for obj in args:
         for key, attr in obj.__dict__.items():
             if (
-                isinstance(attr, _UnaryUnaryMultiCallable)
-                or isinstance(attr, _StreamStreamMultiCallable)
-                or isinstance(attr, _UnaryStreamMultiCallable)
-                or isinstance(attr, _SingleThreadedUnaryStreamMultiCallable)
+                isinstance(attr, UnaryUnaryMultiCallable)
+                or isinstance(attr, StreamStreamMultiCallable)
+                or isinstance(attr, UnaryStreamMultiCallable)
             ):
                 setattr(obj, key, with_retry(attr))
 
@@ -87,7 +80,7 @@ def with_wrapped_rpc_errors(f):
     def wraps(*args, **kwargs):
         try:
             return f(*args, **kwargs)
-        except _InactiveRpcError as e:
+        except grpc.RpcError as e:
             raise _from_grpc_error(e) from None
 
     return wraps
@@ -105,11 +98,13 @@ ParsedUrl = namedtuple("ParsedUrl", "is_insecure target")
 class ApiKeyAuth(grpc.AuthMetadataPlugin):
     "Inject the api-key header with an API key in GRPC requests"
 
+    _metadata: List[Tuple[str, str]]
+
     def __init__(self, project_name: str, api_key: str):
         if project_name is None:
-            self._metadata = (("api-key", api_key),)
+            self._metadata = [("api-key", api_key)]
         else:
-            self._metadata = (("api-key", api_key), ("cdf-project-name", project_name))
+            self._metadata = [("api-key", api_key), ("cdf-project-name", project_name)]
 
     def __call__(self, context, callback):
         callback(self._metadata, None)
@@ -166,6 +161,14 @@ class CogniteSeismicClient:
             This should be either a string or a callable resolving to a string.
     """
 
+    job: "JobAPI"
+    survey: "SurveyAPI"
+    traces: "TracesAPI"
+    partition: "PartitionAPI"
+    seismic: "SeismicAPI"
+    seismicstore: "SeismicStoreAPI"
+    file: "FileAPI"
+
     def __init__(
         self,
         api_key=None,
